Index: util/posix/symbolic_constants_posix_test.cc |
diff --git a/util/posix/symbolic_constants_posix_test.cc b/util/posix/symbolic_constants_posix_test.cc |
index c80d00d9e522b9e1870c132794a44185f1d37174..db3193d45e1840bea680b305baf2610fd3eeceec 100644 |
--- a/util/posix/symbolic_constants_posix_test.cc |
+++ b/util/posix/symbolic_constants_posix_test.cc |
@@ -69,7 +69,7 @@ const struct { |
#endif |
}; |
// If |expect| is NULL, the conversion is expected to fail. If |expect| is |
// empty, the conversion is expected to succeed, but the precise returned string |
// value is unknown. Otherwise, the conversion is expected to succeed, and |
// |expect| contains the precise expected string value to be returned. |
@@ -130,7 +130,7 @@ TEST(SymbolicConstantsPOSIX, SignalToString) { |
if (signal > 0 && signal < kSignalCount) { |
TestSignalToString(signal, "", ""); |
} else { |
- TestSignalToString(signal, NULL, NULL); |
+ TestSignalToString(signal, nullptr, nullptr); |
} |
} |
} |
@@ -69,7 +69,7 @@ const struct { |
#endif |
}; |
-// If |expect| is NULL, the conversion is expected to fail. If |expect| is |
+// If |expect| is nullptr, the conversion is expected to fail. If |expect| is |
// empty, the conversion is expected to succeed, but the precise returned string |
// value is unknown. Otherwise, the conversion is expected to succeed, and |